@@ -105,7 +105,7 @@ void print_hex(const char* what, const void* v, const unsigned long l);
 int compare_testvector(const void* is, const unsigned long is_len, const void* should, const unsigned long should_len, const char* what, int which);
 #else
 #define compare_testvector(is, is_len, should, should_len, what, which) \
-   (((is_len) != (should_len)) || (XMEMCMP((is), (should), (is_len)) != 0))
+   ((((is_len) != (should_len)) || (XMEMCMP((is), (should), (is_len)) != 0)) ? 1 : 0)
 #endif
 
 /* $Source$ */
