@@ -9,7 +9,7 @@
  */
 #include "tomcrypt.h"
 /**
-  @file der_encode_sequence_multi.c
+  @file der_decode_subject_public_key_info.c
   ASN.1 DER, encode a Subject Public Key structure --nmav
 */
 
@@ -26,11 +26,16 @@
  * }
  */
 /**
-  Encode a SEQUENCE type using a VA list
-  @param out    [out] Destination for data
-  @param outlen [in/out] Length of buffer and resulting length of output
-  @remark <...> is of the form <type, size, data> (int, unsigned long, void*)
-  @return CRYPT_OK on success
+  Decode a subject public key info
+   @param in      The input buffer
+   @param inlen   The length of the input buffer
+   @param algorithm             One out of the enum #public_key_algorithms
+   @param public_key            The buffer for the public key
+   @param public_key_len        [in/out] The length of the public key buffer and the written length
+   @param parameters_type       The parameters' type out of the enum #ltc_asn1_type
+   @param parameters            The parameters to include
+   @param parameters_len        The number of parameters to include
+   @return CRYPT_OK on success
 */
 int der_decode_subject_public_key_info(const unsigned char *in, unsigned long inlen,
         unsigned int algorithm, void* public_key, unsigned long* public_key_len,
